#!/usr/bin/env python3

import unittest

import numpy as np

from km3services.oscprob import OscProb


class TestOscProb(unittest.TestCase):
    def test_init(self):
        oscprob = OscProb()
        assert oscprob.url == "http://131.188.161.12:30000"

    def test_oscillationprobabilities(self):
        oscprob = OscProb()

        n = 100
        energies = np.random.randint(1, 50, n)
        cos_zeniths = 1 - np.random.rand(n) * 2
        probabilities = oscprob.oscillationprobabilities(12, 14, energies, cos_zeniths)
        assert np.all(probabilities <= 1)



#!/usr/bin/env python3


class KM3Service:
    """Base class for a KM3NeT service"""

    def __init__(self, server, port, protocol="http"):
        self._server = server
        self._port = port
        self._protocol = protocol

    @property
    def server(self):
        return self._server

    @server.setter
    def server(self, value):
        self._server = value

    @property
    def port(self):
        return self._port

    @port.setter
    def port(self, value):
        self._port = value

    @property
    def protocol(self):
        return self._protocol

    @protocol.setter
    def protocol(self, value):
        self._protocol = value

    @property
    def url(self):
        return f"{self.protocol}://{self.server}:{self.port}"



#!/usr/bin/env python3
import unittest

from km3services.core import KM3Service


class TestKM3Service:
    def test_km3service(self):
        class AService(KM3Service):
            pass

        server = "a_server"
        port = 12345
        protocol = "https"

        a_service = AService(server, port, protocol)

        assert a_service.server == server
        assert a_service.port == port
        assert a_service.protocol == protocol
        assert a_service.url == "https://a_server:12345"
